# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import device_msgs_pb2 as device__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='control_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x63ontrol_msgs.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x64\x65vice_msgs.proto\x1a\x11\x63ommon_msgs.proto\"k\n\x0b\x43ontrolInfo\x12\x17\n\x0f\x63ontrol_version\x18\x01 \x01(\t\x12\x13\n\x0brobot_model\x18\x02 \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\":\n\x0eSDKLicenseInfo\x12\x13\n\x0blicense_key\x18\x01 \x01(\t\x12\x13\n\x0b\x65xpire_date\x18\x02 \x01(\t\"S\n\x0eSDKLicenseResp\x12\x11\n\tactivated\x18\x01 \x01(\x08\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xc1\x02\n\x11VariableCondition\x12/\n\x06i_vars\x18\x01 \x03(\x0b\x32\x1f.Nrmk.IndyFramework.IntVariable\x12\x31\n\x06\x66_vars\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.FloatVariable\x12\x30\n\x06\x62_vars\x18\x03 \x03(\x0b\x32 .Nrmk.IndyFramework.BoolVariable\x12\x32\n\x06m_vars\x18\x04 \x03(\x0b\x32\".Nrmk.IndyFramework.ModbusVariable\x12\x30\n\x06j_vars\x18\x05 \x03(\x0b\x32 .Nrmk.IndyFramework.JPosVariable\x12\x30\n\x06t_vars\x18\x06 \x03(\x0b\x32 .Nrmk.IndyFramework.TPosVariable\"o\n\x0bIOCondition\x12-\n\x02\x64i\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x31\n\x06\x65nd_di\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\"\x96\x03\n\x0fMotionCondition\x12\x44\n\ttype_cond\x18\x01 \x01(\x0e\x32\x31.Nrmk.IndyFramework.MotionCondition.ConditionType\x12\x44\n\ntype_react\x18\x02 \x01(\x0e\x32\x30.Nrmk.IndyFramework.MotionCondition.ReactionType\x12\x12\n\nconst_cond\x18\x03 \x01(\x08\x12\x30\n\x07io_cond\x18\x04 \x01(\x0b\x32\x1f.Nrmk.IndyFramework.IOCondition\x12\x37\n\x08var_cond\x18\x05 \x01(\x0b\x32%.Nrmk.IndyFramework.VariableCondition\":\n\rConditionType\x12\x0e\n\nCONST_COND\x10\x00\x12\x0b\n\x07IO_COND\x10\x01\x12\x0c\n\x08VAR_COND\x10\x02\"<\n\x0cReactionType\x12\r\n\tNONE_COND\x10\x00\x12\r\n\tSTOP_COND\x10\x01\x12\x0e\n\nPAUSE_COND\x10\x02\"\x8b\x01\n\x0c\x42lendingType\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.Nrmk.IndyFramework.BlendingType.Type\x12\x17\n\x0f\x62lending_radius\x18\x02 \x01(\x02\"-\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08OVERRIDE\x10\x01\x12\r\n\tDUPLICATE\x10\x02\"b\n\x07TargetJ\x12\x0f\n\x07j_start\x18\x01 \x03(\x02\x12\x10\n\x08j_target\x18\x02 \x03(\x02\x12\x34\n\tbase_type\x18\x03 \x01(\x0e\x32!.Nrmk.IndyFramework.JointBaseType\"\xe5\x01\n\x08MoveJReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetJ\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x11\n\tvel_ratio\x18\x03 \x01(\x02\x12\x11\n\tacc_ratio\x18\x04 \x01(\x02\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\x12\x15\n\rteaching_mode\x18\x1e \x01(\x08\"\xe9\x01\n\x0cMoveJCondReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetJ\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x11\n\tvel_ratio\x18\x03 \x01(\x02\x12\x11\n\tacc_ratio\x18\x04 \x01(\x02\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\x12\x15\n\rteaching_mode\x18\x1e \x01(\x08\"\xb7\x01\n\tMoveJTReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetJ\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x0c\n\x04time\x18\x03 \x01(\x02\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\"a\n\x07TargetP\x12\x0f\n\x07t_start\x18\x01 \x03(\x02\x12\x10\n\x08t_target\x18\x02 \x03(\x02\x12\x33\n\tbase_type\x18\x03 \x01(\x0e\x32 .Nrmk.IndyFramework.TaskBaseType\"o\n\x07TargetC\x12\x0f\n\x07t_start\x18\x01 \x03(\x02\x12\x0e\n\x06t_pos0\x18\x02 \x03(\x02\x12\x0e\n\x06t_pos1\x18\x03 \x03(\x02\x12\x33\n\tbase_type\x18\x04 \x01(\x0e\x32 .Nrmk.IndyFramework.TaskBaseType\"\x9d\x02\n\x08MoveLReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetP\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x11\n\tvel_ratio\x18\x03 \x01(\x02\x12\x11\n\tacc_ratio\x18\x04 \x01(\x02\x12\x36\n\x08vel_type\x18\x05 \x01(\x0e\x32$.Nrmk.IndyFramework.VelocityModeType\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\x12\x15\n\rteaching_mode\x18\x1e \x01(\x08\"\xb7\x01\n\tMoveLTReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetP\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x0c\n\x04time\x18\x03 \x01(\x02\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\"\xa6\x03\n\x08MoveCReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetC\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\r\n\x05\x61ngle\x18\x03 \x01(\x02\x12=\n\x0csetting_type\x18\n \x01(\x0e\x32\'.Nrmk.IndyFramework.CircularSettingType\x12\x39\n\tmove_type\x18\x0b \x01(\x0e\x32&.Nrmk.IndyFramework.CircularMovingType\x12\x11\n\tvel_ratio\x18\x14 \x01(\x02\x12\x11\n\tacc_ratio\x18\x15 \x01(\x02\x12\x36\n\x08vel_type\x18\x16 \x01(\x0e\x32$.Nrmk.IndyFramework.VelocityModeType\x12;\n\x0epost_condition\x18\x19 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\x12\x15\n\rteaching_mode\x18\x1e \x01(\x08\"\xc0\x02\n\tMoveCTReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetC\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\r\n\x05\x61ngle\x18\x03 \x01(\x02\x12=\n\x0csetting_type\x18\n \x01(\x0e\x32\'.Nrmk.IndyFramework.CircularSettingType\x12\x39\n\tmove_type\x18\x0b \x01(\x0e\x32&.Nrmk.IndyFramework.CircularMovingType\x12\x0c\n\x04time\x18\x14 \x01(\x02\x12;\n\x0epost_condition\x18\x19 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\"\xde\x03\n\tWaitIOReq\x12\x32\n\x07\x64i_list\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x32\n\x07\x64o_list\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x36\n\x0b\x65nd_di_list\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x36\n\x0b\x65nd_do_list\x18\x04 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x13\n\x0b\x63onjunction\x18\x05 \x01(\x05\x12\x36\n\x0bset_do_list\x18\x06 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12:\n\x0fset_end_do_list\x18\x07 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\x0bset_ao_list\x18\x08 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x39\n\x0fset_end_ao_list\x18\t \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\"\x81\x02\n\x0bWaitTimeReq\x12\x0c\n\x04time\x18\x01 \x01(\x02\x12\x36\n\x0bset_do_list\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12:\n\x0fset_end_do_list\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\x0bset_ao_list\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x39\n\x0fset_end_ao_list\x18\x05 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\"\x89\x02\n\x0fWaitProgressReq\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x36\n\x0bset_do_list\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12:\n\x0fset_end_do_list\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\x0bset_ao_list\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x39\n\x0fset_end_ao_list\x18\x05 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\"\xae\x02\n\x0bWaitTrajReq\x12\x39\n\x0etraj_condition\x18\x01 \x01(\x0e\x32!.Nrmk.IndyFramework.TrajCondition\x12\x36\n\x0bset_do_list\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12:\n\x0fset_end_do_list\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\x0bset_ao_list\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x39\n\x0fset_end_ao_list\x18\x05 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\"\x85\x02\n\rWaitRadiusReq\x12\x0e\n\x06radius\x18\x01 \x01(\x05\x12\x36\n\x0bset_do_list\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12:\n\x0fset_end_do_list\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\x0bset_ao_list\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x39\n\x0fset_end_ao_list\x18\x05 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\".\n\x07Program\x12\x11\n\tprog_name\x18\x01 \x01(\t\x12\x10\n\x08prog_idx\x18\x02 \x01(\x05\"\xc3\x01\n\rTuningProgram\x12,\n\x07program\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.Program\x12\x35\n\x0ctuning_space\x18\x02 \x01(\x0e\x32\x1f.Nrmk.IndyFramework.TuningSpace\x12\x36\n\tprecision\x18\x03 \x01(\x0e\x32#.Nrmk.IndyFramework.TuningPrecision\x12\x15\n\rvel_level_max\x18\x04 \x01(\r\"<\n\x0bProgramInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"I\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0bin_watching\x18\x04 \x01(\x08\"*\n\x0bIntVariable\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03\"\xcf\x01\n\x0eModbusVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x05\x12\x42\n\x0bsignal_type\x18\x04 \x01(\x0e\x32-.Nrmk.IndyFramework.ModbusVariable.SignalType\"N\n\nSignalType\x12\x0c\n\x08ReadCoil\x10\x00\x12\r\n\tWriteCoil\x10\x01\x12\x10\n\x0cReadRegister\x10\x02\x12\x11\n\rWriteRegister\x10\x03\"+\n\x0c\x42oolVariable\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\",\n\rFloatVariable\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02\"*\n\x0cJPosVariable\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x05\x12\x0c\n\x04jpos\x18\x02 \x03(\x02\"*\n\x0cTPosVariable\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x05\x12\x0c\n\x04tpos\x18\x02 \x03(\x02\"x\n\x0cModbusServer\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x39\n\rvariable_list\x18\x04 \x03(\x0b\x32\".Nrmk.IndyFramework.ModbusVariable\"P\n\x12ModbusVariableList\x12:\n\x10modbus_variables\x18\x01 \x03(\x0b\x32 .Nrmk.IndyFramework.ModbusServer\":\n\x07\x41llVars\x12/\n\tvariables\x18\x01 \x03(\x0b\x32\x1c.Nrmk.IndyFramework.Variable\"=\n\x07IntVars\x12\x32\n\tvariables\x18\x01 \x03(\x0b\x32\x1f.Nrmk.IndyFramework.IntVariable\"C\n\nModbusVars\x12\x35\n\tvariables\x18\x01 \x03(\x0b\x32\".Nrmk.IndyFramework.ModbusVariable\"?\n\x08\x42oolVars\x12\x33\n\tvariables\x18\x01 \x03(\x0b\x32 .Nrmk.IndyFramework.BoolVariable\"A\n\tFloatVars\x12\x34\n\tvariables\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.FloatVariable\"?\n\x08JPosVars\x12\x33\n\tvariables\x18\x01 \x03(\x0b\x32 .Nrmk.IndyFramework.JPosVariable\"?\n\x08TPosVars\x12\x33\n\tvariables\x18\x01 \x03(\x0b\x32 .Nrmk.IndyFramework.TPosVariable\"7\n\x14InverseKinematicsReq\x12\x0c\n\x04tpos\x18\x01 \x03(\x02\x12\x11\n\tinit_jpos\x18\x02 \x03(\x02\"T\n\x14InverseKinematicsRes\x12\x0c\n\x04jpos\x18\x01 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"c\n\x1b\x43heckAproachRetractValidReq\x12\x0c\n\x04tpos\x18\x01 \x03(\x02\x12\x11\n\tinit_jpos\x18\x02 \x03(\x02\x12\x10\n\x08pre_tpos\x18\x03 \x03(\x02\x12\x11\n\tpost_tpos\x18\x04 \x03(\x02\"\x9b\x01\n\x1b\x43heckAproachRetractValidRes\x12\x10\n\x08is_valid\x18\x01 \x01(\x08\x12\x0f\n\x07tar_pos\x18\x02 \x03(\x02\x12\x14\n\x0c\x61pproach_pos\x18\x03 \x03(\x02\x12\x13\n\x0bretract_pos\x18\x04 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x8f\x01\n\x15GetPalletPointListReq\x12\x0c\n\x04tpos\x18\x01 \x03(\x02\x12\x0c\n\x04jpos\x18\x02 \x03(\x02\x12\x10\n\x08pre_tpos\x18\x03 \x03(\x02\x12\x11\n\tpost_tpos\x18\x04 \x03(\x02\x12\x16\n\x0epallet_pattern\x18\x05 \x01(\x05\x12\r\n\x05width\x18\x06 \x01(\x05\x12\x0e\n\x06height\x18\x07 \x01(\x05\"[\n\x0bPalletPoint\x12\x0f\n\x07tar_pos\x18\x01 \x03(\x02\x12\x14\n\x0c\x61pproach_pos\x18\x02 \x03(\x02\x12\x13\n\x0bretract_pos\x18\x03 \x03(\x02\x12\x10\n\x08tar_jpos\x18\x04 \x03(\x02\"\x7f\n\x15GetPalletPointListRes\x12\x36\n\rpallet_points\x18\x01 \x03(\x0b\x32\x1f.Nrmk.IndyFramework.PalletPoint\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"s\n\x18\x43\x61lculateRelativePoseReq\x12\x11\n\tstart_pos\x18\x01 \x03(\x02\x12\x0f\n\x07\x65nd_pos\x18\x02 \x03(\x02\x12\x33\n\tbase_type\x18\x03 \x01(\x0e\x32 .Nrmk.IndyFramework.TaskBaseType\"`\n\x18\x43\x61lculateRelativePoseRes\x12\x14\n\x0crelative_pos\x18\x01 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"|\n\x1a\x43\x61lculateCurrentPoseRelReq\x12\x13\n\x0b\x63urrent_pos\x18\x01 \x03(\x02\x12\x14\n\x0crelative_pos\x18\x02 \x03(\x02\x12\x33\n\tbase_type\x18\x03 \x01(\x0e\x32 .Nrmk.IndyFramework.TaskBaseType\"d\n\x1a\x43\x61lculateCurrentPoseRelRes\x12\x16\n\x0e\x63\x61lculated_pos\x18\x01 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xb2\x01\n\x0cTeleOpDevice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.Nrmk.IndyFramework.TeleOpDevice.TeleOpDeviceType\x12\n\n\x02ip\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r\x12\x11\n\tconnected\x18\x05 \x01(\x08\"&\n\x10TeleOpDeviceType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04VIVE\x10\x01\"i\n\x0bTeleOpState\x12*\n\x04mode\x18\x01 \x01(\x0e\x32\x1c.Nrmk.IndyFramework.TeleMode\x12.\n\x06method\x18\x02 \x01(\x0e\x32\x1e.Nrmk.IndyFramework.TeleMethod\"E\n\x05TeleP\x12\x0c\n\x04tpos\x18\x01 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"O\n\x0eTeleOpFileList\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x1b\n\x0bTeleFileReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1c\n\x0cTelePlayRate\x12\x0c\n\x04rate\x18\x01 \x01(\x02\"r\n\x0cMoveTeleJReq\x12\x0c\n\x04jpos\x18\x01 \x03(\x02\x12\x11\n\tvel_ratio\x18\x02 \x01(\x02\x12\x11\n\tacc_ratio\x18\x03 \x01(\x02\x12.\n\x06method\x18\n \x01(\x0e\x32\x1e.Nrmk.IndyFramework.TeleMethod\"r\n\x0cMoveTeleLReq\x12\x0c\n\x04tpos\x18\x01 \x03(\x02\x12\x11\n\tvel_ratio\x18\x02 \x01(\x02\x12\x11\n\tacc_ratio\x18\x03 \x01(\x02\x12.\n\x06method\x18\n \x01(\x0e\x32\x1e.Nrmk.IndyFramework.TeleMethod\"\xcd\x02\n\tMoveFLReq\x12+\n\x06target\x18\x01 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.TargetP\x12\x32\n\x08\x62lending\x18\x02 \x01(\x0b\x32 .Nrmk.IndyFramework.BlendingType\x12\x11\n\tvel_ratio\x18\x03 \x01(\x02\x12\x11\n\tacc_ratio\x18\x04 \x01(\x02\x12\x36\n\x08vel_type\x18\x05 \x01(\x0e\x32$.Nrmk.IndyFramework.VelocityModeType\x12\x11\n\tdes_force\x18\x06 \x01(\x02\x12\x1a\n\x12\x65nableForceControl\x18\x07 \x01(\x08\x12;\n\x0epost_condition\x18\x14 \x01(\x0b\x32#.Nrmk.IndyFramework.MotionCondition\x12\x15\n\rteaching_mode\x18\x1e \x01(\x08\"\x18\n\tMoveFLRes\x12\x0b\n\x03msg\x18\x64 \x01(\t*7\n\rJointBaseType\x12\x12\n\x0e\x41\x42SOLUTE_JOINT\x10\x00\x12\x12\n\x0eRELATIVE_JOINT\x10\x01*B\n\x0cTaskBaseType\x12\x11\n\rABSOLUTE_TASK\x10\x00\x12\x11\n\rRELATIVE_TASK\x10\x01\x12\x0c\n\x08TCP_TASK\x10\x02*J\n\x10VelocityModeType\x12\x11\n\rTIME_ORIENTED\x10\x00\x12\x11\n\rDISP_ORIENTED\x10\x01\x12\x10\n\x0cROT_ORIENTED\x10\x02*5\n\x13\x43ircularSettingType\x12\r\n\tPOINT_SET\x10\x00\x12\x0f\n\x0b\x43\x45NTER_AXIS\x10\x01*:\n\x12\x43ircularMovingType\x12\x0c\n\x08\x43ONSTANT\x10\x00\x12\n\n\x06RADIAL\x10\x01\x12\n\n\x06SMOOTH\x10\x02*j\n\x08TeleMode\x12\x11\n\rTELE_INACTIVE\x10\x00\x12\x0e\n\nTELE_CALIB\x10\x01\x12\x0f\n\x0bTELE_RECORD\x10\x02\x12\r\n\tTELE_PLAY\x10\x03\x12\x0c\n\x08TELE_RAW\x10\n\x12\r\n\tTELE_MOVE\x10\x14*\x9b\x01\n\nTeleMethod\x12\x16\n\x12TELE_TASK_ABSOLUTE\x10\x00\x12\x16\n\x12TELE_TASK_RELATIVE\x10\x01\x12\x11\n\rTELE_TASK_TCP\x10\x02\x12\x17\n\x13TELE_JOINT_ABSOLUTE\x10\n\x12\x17\n\x13TELE_JOINT_RELATIVE\x10\x0b\x12\x18\n\x14TELE_RECORD_ABSOLUTE\x10\x14\x62\x06proto3'
  ,
  dependencies=[device__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])

_JOINTBASETYPE = _descriptor.EnumDescriptor(
  name='JointBaseType',
  full_name='Nrmk.IndyFramework.JointBaseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABSOLUTE_JOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_JOINT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8868,
  serialized_end=8923,
)
_sym_db.RegisterEnumDescriptor(_JOINTBASETYPE)

JointBaseType = enum_type_wrapper.EnumTypeWrapper(_JOINTBASETYPE)
_TASKBASETYPE = _descriptor.EnumDescriptor(
  name='TaskBaseType',
  full_name='Nrmk.IndyFramework.TaskBaseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABSOLUTE_TASK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_TASK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP_TASK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8925,
  serialized_end=8991,
)
_sym_db.RegisterEnumDescriptor(_TASKBASETYPE)

TaskBaseType = enum_type_wrapper.EnumTypeWrapper(_TASKBASETYPE)
_VELOCITYMODETYPE = _descriptor.EnumDescriptor(
  name='VelocityModeType',
  full_name='Nrmk.IndyFramework.VelocityModeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME_ORIENTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISP_ORIENTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROT_ORIENTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8993,
  serialized_end=9067,
)
_sym_db.RegisterEnumDescriptor(_VELOCITYMODETYPE)

VelocityModeType = enum_type_wrapper.EnumTypeWrapper(_VELOCITYMODETYPE)
_CIRCULARSETTINGTYPE = _descriptor.EnumDescriptor(
  name='CircularSettingType',
  full_name='Nrmk.IndyFramework.CircularSettingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POINT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CENTER_AXIS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9069,
  serialized_end=9122,
)
_sym_db.RegisterEnumDescriptor(_CIRCULARSETTINGTYPE)

CircularSettingType = enum_type_wrapper.EnumTypeWrapper(_CIRCULARSETTINGTYPE)
_CIRCULARMOVINGTYPE = _descriptor.EnumDescriptor(
  name='CircularMovingType',
  full_name='Nrmk.IndyFramework.CircularMovingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSTANT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RADIAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOOTH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9124,
  serialized_end=9182,
)
_sym_db.RegisterEnumDescriptor(_CIRCULARMOVINGTYPE)

CircularMovingType = enum_type_wrapper.EnumTypeWrapper(_CIRCULARMOVINGTYPE)
_TELEMODE = _descriptor.EnumDescriptor(
  name='TeleMode',
  full_name='Nrmk.IndyFramework.TeleMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TELE_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_CALIB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_RECORD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_PLAY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_RAW', index=4, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_MOVE', index=5, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9184,
  serialized_end=9290,
)
_sym_db.RegisterEnumDescriptor(_TELEMODE)

TeleMode = enum_type_wrapper.EnumTypeWrapper(_TELEMODE)
_TELEMETHOD = _descriptor.EnumDescriptor(
  name='TeleMethod',
  full_name='Nrmk.IndyFramework.TeleMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TELE_TASK_ABSOLUTE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_TASK_RELATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_TASK_TCP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_JOINT_ABSOLUTE', index=3, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_JOINT_RELATIVE', index=4, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_RECORD_ABSOLUTE', index=5, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9293,
  serialized_end=9448,
)
_sym_db.RegisterEnumDescriptor(_TELEMETHOD)

TeleMethod = enum_type_wrapper.EnumTypeWrapper(_TELEMETHOD)
ABSOLUTE_JOINT = 0
RELATIVE_JOINT = 1
ABSOLUTE_TASK = 0
RELATIVE_TASK = 1
TCP_TASK = 2
TIME_ORIENTED = 0
DISP_ORIENTED = 1
ROT_ORIENTED = 2
POINT_SET = 0
CENTER_AXIS = 1
CONSTANT = 0
RADIAL = 1
SMOOTH = 2
TELE_INACTIVE = 0
TELE_CALIB = 1
TELE_RECORD = 2
TELE_PLAY = 3
TELE_RAW = 10
TELE_MOVE = 20
TELE_TASK_ABSOLUTE = 0
TELE_TASK_RELATIVE = 1
TELE_TASK_TCP = 2
TELE_JOINT_ABSOLUTE = 10
TELE_JOINT_RELATIVE = 11
TELE_RECORD_ABSOLUTE = 20


_MOTIONCONDITION_CONDITIONTYPE = _descriptor.EnumDescriptor(
  name='ConditionType',
  full_name='Nrmk.IndyFramework.MotionCondition.ConditionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONST_COND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_COND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VAR_COND', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1058,
  serialized_end=1116,
)
_sym_db.RegisterEnumDescriptor(_MOTIONCONDITION_CONDITIONTYPE)

_MOTIONCONDITION_REACTIONTYPE = _descriptor.EnumDescriptor(
  name='ReactionType',
  full_name='Nrmk.IndyFramework.MotionCondition.ReactionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE_COND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_COND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSE_COND', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1118,
  serialized_end=1178,
)
_sym_db.RegisterEnumDescriptor(_MOTIONCONDITION_REACTIONTYPE)

_BLENDINGTYPE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='Nrmk.IndyFramework.BlendingType.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERRIDE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1275,
  serialized_end=1320,
)
_sym_db.RegisterEnumDescriptor(_BLENDINGTYPE_TYPE)

_MODBUSVARIABLE_SIGNALTYPE = _descriptor.EnumDescriptor(
  name='SignalType',
  full_name='Nrmk.IndyFramework.ModbusVariable.SignalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ReadCoil', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WriteCoil', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ReadRegister', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WriteRegister', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5645,
  serialized_end=5723,
)
_sym_db.RegisterEnumDescriptor(_MODBUSVARIABLE_SIGNALTYPE)

_TELEOPDEVICE_TELEOPDEVICETYPE = _descriptor.EnumDescriptor(
  name='TeleOpDeviceType',
  full_name='Nrmk.IndyFramework.TeleOpDevice.TeleOpDeviceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7916,
  serialized_end=7954,
)
_sym_db.RegisterEnumDescriptor(_TELEOPDEVICE_TELEOPDEVICETYPE)


_CONTROLINFO = _descriptor.Descriptor(
  name='ControlInfo',
  full_name='Nrmk.IndyFramework.ControlInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_version', full_name='Nrmk.IndyFramework.ControlInfo.control_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_model', full_name='Nrmk.IndyFramework.ControlInfo.robot_model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ControlInfo.response', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=187,
)


_SDKLICENSEINFO = _descriptor.Descriptor(
  name='SDKLicenseInfo',
  full_name='Nrmk.IndyFramework.SDKLicenseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='license_key', full_name='Nrmk.IndyFramework.SDKLicenseInfo.license_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_date', full_name='Nrmk.IndyFramework.SDKLicenseInfo.expire_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=247,
)


_SDKLICENSERESP = _descriptor.Descriptor(
  name='SDKLicenseResp',
  full_name='Nrmk.IndyFramework.SDKLicenseResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activated', full_name='Nrmk.IndyFramework.SDKLicenseResp.activated', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.SDKLicenseResp.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=332,
)


_VARIABLECONDITION = _descriptor.Descriptor(
  name='VariableCondition',
  full_name='Nrmk.IndyFramework.VariableCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='i_vars', full_name='Nrmk.IndyFramework.VariableCondition.i_vars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f_vars', full_name='Nrmk.IndyFramework.VariableCondition.f_vars', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b_vars', full_name='Nrmk.IndyFramework.VariableCondition.b_vars', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m_vars', full_name='Nrmk.IndyFramework.VariableCondition.m_vars', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_vars', full_name='Nrmk.IndyFramework.VariableCondition.j_vars', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_vars', full_name='Nrmk.IndyFramework.VariableCondition.t_vars', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=656,
)


_IOCONDITION = _descriptor.Descriptor(
  name='IOCondition',
  full_name='Nrmk.IndyFramework.IOCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di', full_name='Nrmk.IndyFramework.IOCondition.di', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_di', full_name='Nrmk.IndyFramework.IOCondition.end_di', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=769,
)


_MOTIONCONDITION = _descriptor.Descriptor(
  name='MotionCondition',
  full_name='Nrmk.IndyFramework.MotionCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_cond', full_name='Nrmk.IndyFramework.MotionCondition.type_cond', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_react', full_name='Nrmk.IndyFramework.MotionCondition.type_react', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='const_cond', full_name='Nrmk.IndyFramework.MotionCondition.const_cond', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_cond', full_name='Nrmk.IndyFramework.MotionCondition.io_cond', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='var_cond', full_name='Nrmk.IndyFramework.MotionCondition.var_cond', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONCONDITION_CONDITIONTYPE,
    _MOTIONCONDITION_REACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=1178,
)


_BLENDINGTYPE = _descriptor.Descriptor(
  name='BlendingType',
  full_name='Nrmk.IndyFramework.BlendingType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Nrmk.IndyFramework.BlendingType.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending_radius', full_name='Nrmk.IndyFramework.BlendingType.blending_radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BLENDINGTYPE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1320,
)


_TARGETJ = _descriptor.Descriptor(
  name='TargetJ',
  full_name='Nrmk.IndyFramework.TargetJ',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='j_start', full_name='Nrmk.IndyFramework.TargetJ.j_start', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_target', full_name='Nrmk.IndyFramework.TargetJ.j_target', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_type', full_name='Nrmk.IndyFramework.TargetJ.base_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1420,
)


_MOVEJREQ = _descriptor.Descriptor(
  name='MoveJReq',
  full_name='Nrmk.IndyFramework.MoveJReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveJReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveJReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveJReq.vel_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveJReq.acc_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveJReq.post_condition', index=4,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_mode', full_name='Nrmk.IndyFramework.MoveJReq.teaching_mode', index=5,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1652,
)


_MOVEJCONDREQ = _descriptor.Descriptor(
  name='MoveJCondReq',
  full_name='Nrmk.IndyFramework.MoveJCondReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveJCondReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveJCondReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveJCondReq.vel_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveJCondReq.acc_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveJCondReq.post_condition', index=4,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_mode', full_name='Nrmk.IndyFramework.MoveJCondReq.teaching_mode', index=5,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1888,
)


_MOVEJTREQ = _descriptor.Descriptor(
  name='MoveJTReq',
  full_name='Nrmk.IndyFramework.MoveJTReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveJTReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveJTReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Nrmk.IndyFramework.MoveJTReq.time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveJTReq.post_condition', index=3,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1891,
  serialized_end=2074,
)


_TARGETP = _descriptor.Descriptor(
  name='TargetP',
  full_name='Nrmk.IndyFramework.TargetP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='t_start', full_name='Nrmk.IndyFramework.TargetP.t_start', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_target', full_name='Nrmk.IndyFramework.TargetP.t_target', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_type', full_name='Nrmk.IndyFramework.TargetP.base_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2076,
  serialized_end=2173,
)


_TARGETC = _descriptor.Descriptor(
  name='TargetC',
  full_name='Nrmk.IndyFramework.TargetC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='t_start', full_name='Nrmk.IndyFramework.TargetC.t_start', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_pos0', full_name='Nrmk.IndyFramework.TargetC.t_pos0', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_pos1', full_name='Nrmk.IndyFramework.TargetC.t_pos1', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_type', full_name='Nrmk.IndyFramework.TargetC.base_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2175,
  serialized_end=2286,
)


_MOVELREQ = _descriptor.Descriptor(
  name='MoveLReq',
  full_name='Nrmk.IndyFramework.MoveLReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveLReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveLReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveLReq.vel_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveLReq.acc_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_type', full_name='Nrmk.IndyFramework.MoveLReq.vel_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveLReq.post_condition', index=5,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_mode', full_name='Nrmk.IndyFramework.MoveLReq.teaching_mode', index=6,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2289,
  serialized_end=2574,
)


_MOVELTREQ = _descriptor.Descriptor(
  name='MoveLTReq',
  full_name='Nrmk.IndyFramework.MoveLTReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveLTReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveLTReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Nrmk.IndyFramework.MoveLTReq.time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveLTReq.post_condition', index=3,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2577,
  serialized_end=2760,
)


_MOVECREQ = _descriptor.Descriptor(
  name='MoveCReq',
  full_name='Nrmk.IndyFramework.MoveCReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveCReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveCReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle', full_name='Nrmk.IndyFramework.MoveCReq.angle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting_type', full_name='Nrmk.IndyFramework.MoveCReq.setting_type', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_type', full_name='Nrmk.IndyFramework.MoveCReq.move_type', index=4,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveCReq.vel_ratio', index=5,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveCReq.acc_ratio', index=6,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_type', full_name='Nrmk.IndyFramework.MoveCReq.vel_type', index=7,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveCReq.post_condition', index=8,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_mode', full_name='Nrmk.IndyFramework.MoveCReq.teaching_mode', index=9,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=3185,
)


_MOVECTREQ = _descriptor.Descriptor(
  name='MoveCTReq',
  full_name='Nrmk.IndyFramework.MoveCTReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveCTReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveCTReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle', full_name='Nrmk.IndyFramework.MoveCTReq.angle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting_type', full_name='Nrmk.IndyFramework.MoveCTReq.setting_type', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_type', full_name='Nrmk.IndyFramework.MoveCTReq.move_type', index=4,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Nrmk.IndyFramework.MoveCTReq.time', index=5,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveCTReq.post_condition', index=6,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3188,
  serialized_end=3508,
)


_WAITIOREQ = _descriptor.Descriptor(
  name='WaitIOReq',
  full_name='Nrmk.IndyFramework.WaitIOReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di_list', full_name='Nrmk.IndyFramework.WaitIOReq.di_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_list', full_name='Nrmk.IndyFramework.WaitIOReq.do_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_di_list', full_name='Nrmk.IndyFramework.WaitIOReq.end_di_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_do_list', full_name='Nrmk.IndyFramework.WaitIOReq.end_do_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conjunction', full_name='Nrmk.IndyFramework.WaitIOReq.conjunction', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_do_list', full_name='Nrmk.IndyFramework.WaitIOReq.set_do_list', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_do_list', full_name='Nrmk.IndyFramework.WaitIOReq.set_end_do_list', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ao_list', full_name='Nrmk.IndyFramework.WaitIOReq.set_ao_list', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_ao_list', full_name='Nrmk.IndyFramework.WaitIOReq.set_end_ao_list', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3511,
  serialized_end=3989,
)


_WAITTIMEREQ = _descriptor.Descriptor(
  name='WaitTimeReq',
  full_name='Nrmk.IndyFramework.WaitTimeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='Nrmk.IndyFramework.WaitTimeReq.time', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_do_list', full_name='Nrmk.IndyFramework.WaitTimeReq.set_do_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_do_list', full_name='Nrmk.IndyFramework.WaitTimeReq.set_end_do_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ao_list', full_name='Nrmk.IndyFramework.WaitTimeReq.set_ao_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_ao_list', full_name='Nrmk.IndyFramework.WaitTimeReq.set_end_ao_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3992,
  serialized_end=4249,
)


_WAITPROGRESSREQ = _descriptor.Descriptor(
  name='WaitProgressReq',
  full_name='Nrmk.IndyFramework.WaitProgressReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='Nrmk.IndyFramework.WaitProgressReq.progress', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_do_list', full_name='Nrmk.IndyFramework.WaitProgressReq.set_do_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_do_list', full_name='Nrmk.IndyFramework.WaitProgressReq.set_end_do_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ao_list', full_name='Nrmk.IndyFramework.WaitProgressReq.set_ao_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_ao_list', full_name='Nrmk.IndyFramework.WaitProgressReq.set_end_ao_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4252,
  serialized_end=4517,
)


_WAITTRAJREQ = _descriptor.Descriptor(
  name='WaitTrajReq',
  full_name='Nrmk.IndyFramework.WaitTrajReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traj_condition', full_name='Nrmk.IndyFramework.WaitTrajReq.traj_condition', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_do_list', full_name='Nrmk.IndyFramework.WaitTrajReq.set_do_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_do_list', full_name='Nrmk.IndyFramework.WaitTrajReq.set_end_do_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ao_list', full_name='Nrmk.IndyFramework.WaitTrajReq.set_ao_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_ao_list', full_name='Nrmk.IndyFramework.WaitTrajReq.set_end_ao_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4520,
  serialized_end=4822,
)


_WAITRADIUSREQ = _descriptor.Descriptor(
  name='WaitRadiusReq',
  full_name='Nrmk.IndyFramework.WaitRadiusReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='Nrmk.IndyFramework.WaitRadiusReq.radius', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_do_list', full_name='Nrmk.IndyFramework.WaitRadiusReq.set_do_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_do_list', full_name='Nrmk.IndyFramework.WaitRadiusReq.set_end_do_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ao_list', full_name='Nrmk.IndyFramework.WaitRadiusReq.set_ao_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_end_ao_list', full_name='Nrmk.IndyFramework.WaitRadiusReq.set_end_ao_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4825,
  serialized_end=5086,
)


_PROGRAM = _descriptor.Descriptor(
  name='Program',
  full_name='Nrmk.IndyFramework.Program',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prog_name', full_name='Nrmk.IndyFramework.Program.prog_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prog_idx', full_name='Nrmk.IndyFramework.Program.prog_idx', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5088,
  serialized_end=5134,
)


_TUNINGPROGRAM = _descriptor.Descriptor(
  name='TuningProgram',
  full_name='Nrmk.IndyFramework.TuningProgram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='program', full_name='Nrmk.IndyFramework.TuningProgram.program', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuning_space', full_name='Nrmk.IndyFramework.TuningProgram.tuning_space', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precision', full_name='Nrmk.IndyFramework.TuningProgram.precision', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_level_max', full_name='Nrmk.IndyFramework.TuningProgram.vel_level_max', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5137,
  serialized_end=5332,
)


_PROGRAMINFO = _descriptor.Descriptor(
  name='ProgramInfo',
  full_name='Nrmk.IndyFramework.ProgramInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Nrmk.IndyFramework.ProgramInfo.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='Nrmk.IndyFramework.ProgramInfo.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='Nrmk.IndyFramework.ProgramInfo.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5334,
  serialized_end=5394,
)


_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='Nrmk.IndyFramework.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Nrmk.IndyFramework.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.Variable.addr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Nrmk.IndyFramework.Variable.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_watching', full_name='Nrmk.IndyFramework.Variable.in_watching', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5396,
  serialized_end=5469,
)


_INTVARIABLE = _descriptor.Descriptor(
  name='IntVariable',
  full_name='Nrmk.IndyFramework.IntVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.IntVariable.addr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.IntVariable.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5471,
  serialized_end=5513,
)


_MODBUSVARIABLE = _descriptor.Descriptor(
  name='ModbusVariable',
  full_name='Nrmk.IndyFramework.ModbusVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Nrmk.IndyFramework.ModbusVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.ModbusVariable.addr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.ModbusVariable.value', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_type', full_name='Nrmk.IndyFramework.ModbusVariable.signal_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MODBUSVARIABLE_SIGNALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5516,
  serialized_end=5723,
)


_BOOLVARIABLE = _descriptor.Descriptor(
  name='BoolVariable',
  full_name='Nrmk.IndyFramework.BoolVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.BoolVariable.addr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.BoolVariable.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5725,
  serialized_end=5768,
)


_FLOATVARIABLE = _descriptor.Descriptor(
  name='FloatVariable',
  full_name='Nrmk.IndyFramework.FloatVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.FloatVariable.addr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.FloatVariable.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5770,
  serialized_end=5814,
)


_JPOSVARIABLE = _descriptor.Descriptor(
  name='JPosVariable',
  full_name='Nrmk.IndyFramework.JPosVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.JPosVariable.addr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jpos', full_name='Nrmk.IndyFramework.JPosVariable.jpos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5816,
  serialized_end=5858,
)


_TPOSVARIABLE = _descriptor.Descriptor(
  name='TPosVariable',
  full_name='Nrmk.IndyFramework.TPosVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='Nrmk.IndyFramework.TPosVariable.addr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.TPosVariable.tpos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5860,
  serialized_end=5902,
)


_MODBUSSERVER = _descriptor.Descriptor(
  name='ModbusServer',
  full_name='Nrmk.IndyFramework.ModbusServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_name', full_name='Nrmk.IndyFramework.ModbusServer.server_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='Nrmk.IndyFramework.ModbusServer.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Nrmk.IndyFramework.ModbusServer.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_list', full_name='Nrmk.IndyFramework.ModbusServer.variable_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5904,
  serialized_end=6024,
)


_MODBUSVARIABLELIST = _descriptor.Descriptor(
  name='ModbusVariableList',
  full_name='Nrmk.IndyFramework.ModbusVariableList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modbus_variables', full_name='Nrmk.IndyFramework.ModbusVariableList.modbus_variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6026,
  serialized_end=6106,
)


_ALLVARS = _descriptor.Descriptor(
  name='AllVars',
  full_name='Nrmk.IndyFramework.AllVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.AllVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6108,
  serialized_end=6166,
)


_INTVARS = _descriptor.Descriptor(
  name='IntVars',
  full_name='Nrmk.IndyFramework.IntVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.IntVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6168,
  serialized_end=6229,
)


_MODBUSVARS = _descriptor.Descriptor(
  name='ModbusVars',
  full_name='Nrmk.IndyFramework.ModbusVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.ModbusVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6231,
  serialized_end=6298,
)


_BOOLVARS = _descriptor.Descriptor(
  name='BoolVars',
  full_name='Nrmk.IndyFramework.BoolVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.BoolVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6300,
  serialized_end=6363,
)


_FLOATVARS = _descriptor.Descriptor(
  name='FloatVars',
  full_name='Nrmk.IndyFramework.FloatVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.FloatVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6365,
  serialized_end=6430,
)


_JPOSVARS = _descriptor.Descriptor(
  name='JPosVars',
  full_name='Nrmk.IndyFramework.JPosVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.JPosVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6432,
  serialized_end=6495,
)


_TPOSVARS = _descriptor.Descriptor(
  name='TPosVars',
  full_name='Nrmk.IndyFramework.TPosVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='Nrmk.IndyFramework.TPosVars.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6497,
  serialized_end=6560,
)


_INVERSEKINEMATICSREQ = _descriptor.Descriptor(
  name='InverseKinematicsReq',
  full_name='Nrmk.IndyFramework.InverseKinematicsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.InverseKinematicsReq.tpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_jpos', full_name='Nrmk.IndyFramework.InverseKinematicsReq.init_jpos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6562,
  serialized_end=6617,
)


_INVERSEKINEMATICSRES = _descriptor.Descriptor(
  name='InverseKinematicsRes',
  full_name='Nrmk.IndyFramework.InverseKinematicsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jpos', full_name='Nrmk.IndyFramework.InverseKinematicsRes.jpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.InverseKinematicsRes.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6619,
  serialized_end=6703,
)


_CHECKAPROACHRETRACTVALIDREQ = _descriptor.Descriptor(
  name='CheckAproachRetractValidReq',
  full_name='Nrmk.IndyFramework.CheckAproachRetractValidReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidReq.tpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_jpos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidReq.init_jpos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre_tpos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidReq.pre_tpos', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_tpos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidReq.post_tpos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6705,
  serialized_end=6804,
)


_CHECKAPROACHRETRACTVALIDRES = _descriptor.Descriptor(
  name='CheckAproachRetractValidRes',
  full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_valid', full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes.is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tar_pos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes.tar_pos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approach_pos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes.approach_pos', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retract_pos', full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes.retract_pos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.CheckAproachRetractValidRes.response', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6807,
  serialized_end=6962,
)


_GETPALLETPOINTLISTREQ = _descriptor.Descriptor(
  name='GetPalletPointListReq',
  full_name='Nrmk.IndyFramework.GetPalletPointListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.GetPalletPointListReq.tpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jpos', full_name='Nrmk.IndyFramework.GetPalletPointListReq.jpos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre_tpos', full_name='Nrmk.IndyFramework.GetPalletPointListReq.pre_tpos', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_tpos', full_name='Nrmk.IndyFramework.GetPalletPointListReq.post_tpos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pallet_pattern', full_name='Nrmk.IndyFramework.GetPalletPointListReq.pallet_pattern', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='Nrmk.IndyFramework.GetPalletPointListReq.width', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='Nrmk.IndyFramework.GetPalletPointListReq.height', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6965,
  serialized_end=7108,
)


_PALLETPOINT = _descriptor.Descriptor(
  name='PalletPoint',
  full_name='Nrmk.IndyFramework.PalletPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tar_pos', full_name='Nrmk.IndyFramework.PalletPoint.tar_pos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approach_pos', full_name='Nrmk.IndyFramework.PalletPoint.approach_pos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retract_pos', full_name='Nrmk.IndyFramework.PalletPoint.retract_pos', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tar_jpos', full_name='Nrmk.IndyFramework.PalletPoint.tar_jpos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7110,
  serialized_end=7201,
)


_GETPALLETPOINTLISTRES = _descriptor.Descriptor(
  name='GetPalletPointListRes',
  full_name='Nrmk.IndyFramework.GetPalletPointListRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pallet_points', full_name='Nrmk.IndyFramework.GetPalletPointListRes.pallet_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.GetPalletPointListRes.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7203,
  serialized_end=7330,
)


_CALCULATERELATIVEPOSEREQ = _descriptor.Descriptor(
  name='CalculateRelativePoseReq',
  full_name='Nrmk.IndyFramework.CalculateRelativePoseReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_pos', full_name='Nrmk.IndyFramework.CalculateRelativePoseReq.start_pos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_pos', full_name='Nrmk.IndyFramework.CalculateRelativePoseReq.end_pos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_type', full_name='Nrmk.IndyFramework.CalculateRelativePoseReq.base_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7332,
  serialized_end=7447,
)


_CALCULATERELATIVEPOSERES = _descriptor.Descriptor(
  name='CalculateRelativePoseRes',
  full_name='Nrmk.IndyFramework.CalculateRelativePoseRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relative_pos', full_name='Nrmk.IndyFramework.CalculateRelativePoseRes.relative_pos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.CalculateRelativePoseRes.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7449,
  serialized_end=7545,
)


_CALCULATECURRENTPOSERELREQ = _descriptor.Descriptor(
  name='CalculateCurrentPoseRelReq',
  full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_pos', full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelReq.current_pos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_pos', full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelReq.relative_pos', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_type', full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelReq.base_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7547,
  serialized_end=7671,
)


_CALCULATECURRENTPOSERELRES = _descriptor.Descriptor(
  name='CalculateCurrentPoseRelRes',
  full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calculated_pos', full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelRes.calculated_pos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.CalculateCurrentPoseRelRes.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7673,
  serialized_end=7773,
)


_TELEOPDEVICE = _descriptor.Descriptor(
  name='TeleOpDevice',
  full_name='Nrmk.IndyFramework.TeleOpDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Nrmk.IndyFramework.TeleOpDevice.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Nrmk.IndyFramework.TeleOpDevice.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='Nrmk.IndyFramework.TeleOpDevice.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Nrmk.IndyFramework.TeleOpDevice.port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connected', full_name='Nrmk.IndyFramework.TeleOpDevice.connected', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TELEOPDEVICE_TELEOPDEVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7776,
  serialized_end=7954,
)


_TELEOPSTATE = _descriptor.Descriptor(
  name='TeleOpState',
  full_name='Nrmk.IndyFramework.TeleOpState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='Nrmk.IndyFramework.TeleOpState.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='Nrmk.IndyFramework.TeleOpState.method', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7956,
  serialized_end=8061,
)


_TELEP = _descriptor.Descriptor(
  name='TeleP',
  full_name='Nrmk.IndyFramework.TeleP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.TeleP.tpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.TeleP.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8063,
  serialized_end=8132,
)


_TELEOPFILELIST = _descriptor.Descriptor(
  name='TeleOpFileList',
  full_name='Nrmk.IndyFramework.TeleOpFileList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='Nrmk.IndyFramework.TeleOpFileList.files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.TeleOpFileList.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8134,
  serialized_end=8213,
)


_TELEFILEREQ = _descriptor.Descriptor(
  name='TeleFileReq',
  full_name='Nrmk.IndyFramework.TeleFileReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Nrmk.IndyFramework.TeleFileReq.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8215,
  serialized_end=8242,
)


_TELEPLAYRATE = _descriptor.Descriptor(
  name='TelePlayRate',
  full_name='Nrmk.IndyFramework.TelePlayRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate', full_name='Nrmk.IndyFramework.TelePlayRate.rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8244,
  serialized_end=8272,
)


_MOVETELEJREQ = _descriptor.Descriptor(
  name='MoveTeleJReq',
  full_name='Nrmk.IndyFramework.MoveTeleJReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jpos', full_name='Nrmk.IndyFramework.MoveTeleJReq.jpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveTeleJReq.vel_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveTeleJReq.acc_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='Nrmk.IndyFramework.MoveTeleJReq.method', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8274,
  serialized_end=8388,
)


_MOVETELELREQ = _descriptor.Descriptor(
  name='MoveTeleLReq',
  full_name='Nrmk.IndyFramework.MoveTeleLReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tpos', full_name='Nrmk.IndyFramework.MoveTeleLReq.tpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveTeleLReq.vel_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveTeleLReq.acc_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='Nrmk.IndyFramework.MoveTeleLReq.method', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8390,
  serialized_end=8504,
)


_MOVEFLREQ = _descriptor.Descriptor(
  name='MoveFLReq',
  full_name='Nrmk.IndyFramework.MoveFLReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Nrmk.IndyFramework.MoveFLReq.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blending', full_name='Nrmk.IndyFramework.MoveFLReq.blending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_ratio', full_name='Nrmk.IndyFramework.MoveFLReq.vel_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_ratio', full_name='Nrmk.IndyFramework.MoveFLReq.acc_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_type', full_name='Nrmk.IndyFramework.MoveFLReq.vel_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='des_force', full_name='Nrmk.IndyFramework.MoveFLReq.des_force', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enableForceControl', full_name='Nrmk.IndyFramework.MoveFLReq.enableForceControl', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_condition', full_name='Nrmk.IndyFramework.MoveFLReq.post_condition', index=7,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_mode', full_name='Nrmk.IndyFramework.MoveFLReq.teaching_mode', index=8,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8507,
  serialized_end=8840,
)


_MOVEFLRES = _descriptor.Descriptor(
  name='MoveFLRes',
  full_name='Nrmk.IndyFramework.MoveFLRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='Nrmk.IndyFramework.MoveFLRes.msg', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8842,
  serialized_end=8866,
)

_CONTROLINFO.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_SDKLICENSERESP.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_VARIABLECONDITION.fields_by_name['i_vars'].message_type = _INTVARIABLE
_VARIABLECONDITION.fields_by_name['f_vars'].message_type = _FLOATVARIABLE
_VARIABLECONDITION.fields_by_name['b_vars'].message_type = _BOOLVARIABLE
_VARIABLECONDITION.fields_by_name['m_vars'].message_type = _MODBUSVARIABLE
_VARIABLECONDITION.fields_by_name['j_vars'].message_type = _JPOSVARIABLE
_VARIABLECONDITION.fields_by_name['t_vars'].message_type = _TPOSVARIABLE
_IOCONDITION.fields_by_name['di'].message_type = device__msgs__pb2._DIGITALSIGNAL
_IOCONDITION.fields_by_name['end_di'].message_type = device__msgs__pb2._DIGITALSIGNAL
_MOTIONCONDITION.fields_by_name['type_cond'].enum_type = _MOTIONCONDITION_CONDITIONTYPE
_MOTIONCONDITION.fields_by_name['type_react'].enum_type = _MOTIONCONDITION_REACTIONTYPE
_MOTIONCONDITION.fields_by_name['io_cond'].message_type = _IOCONDITION
_MOTIONCONDITION.fields_by_name['var_cond'].message_type = _VARIABLECONDITION
_MOTIONCONDITION_CONDITIONTYPE.containing_type = _MOTIONCONDITION
_MOTIONCONDITION_REACTIONTYPE.containing_type = _MOTIONCONDITION
_BLENDINGTYPE.fields_by_name['type'].enum_type = _BLENDINGTYPE_TYPE
_BLENDINGTYPE_TYPE.containing_type = _BLENDINGTYPE
_TARGETJ.fields_by_name['base_type'].enum_type = _JOINTBASETYPE
_MOVEJREQ.fields_by_name['target'].message_type = _TARGETJ
_MOVEJREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVEJREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_MOVEJCONDREQ.fields_by_name['target'].message_type = _TARGETJ
_MOVEJCONDREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVEJCONDREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_MOVEJTREQ.fields_by_name['target'].message_type = _TARGETJ
_MOVEJTREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVEJTREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_TARGETP.fields_by_name['base_type'].enum_type = _TASKBASETYPE
_TARGETC.fields_by_name['base_type'].enum_type = _TASKBASETYPE
_MOVELREQ.fields_by_name['target'].message_type = _TARGETP
_MOVELREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVELREQ.fields_by_name['vel_type'].enum_type = _VELOCITYMODETYPE
_MOVELREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_MOVELTREQ.fields_by_name['target'].message_type = _TARGETP
_MOVELTREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVELTREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_MOVECREQ.fields_by_name['target'].message_type = _TARGETC
_MOVECREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVECREQ.fields_by_name['setting_type'].enum_type = _CIRCULARSETTINGTYPE
_MOVECREQ.fields_by_name['move_type'].enum_type = _CIRCULARMOVINGTYPE
_MOVECREQ.fields_by_name['vel_type'].enum_type = _VELOCITYMODETYPE
_MOVECREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_MOVECTREQ.fields_by_name['target'].message_type = _TARGETC
_MOVECTREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVECTREQ.fields_by_name['setting_type'].enum_type = _CIRCULARSETTINGTYPE
_MOVECTREQ.fields_by_name['move_type'].enum_type = _CIRCULARMOVINGTYPE
_MOVECTREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
_WAITIOREQ.fields_by_name['di_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['end_di_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['set_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['set_end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITIOREQ.fields_by_name['set_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITIOREQ.fields_by_name['set_end_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITTIMEREQ.fields_by_name['set_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITTIMEREQ.fields_by_name['set_end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITTIMEREQ.fields_by_name['set_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITTIMEREQ.fields_by_name['set_end_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITPROGRESSREQ.fields_by_name['set_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITPROGRESSREQ.fields_by_name['set_end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITPROGRESSREQ.fields_by_name['set_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITPROGRESSREQ.fields_by_name['set_end_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITTRAJREQ.fields_by_name['traj_condition'].enum_type = common__msgs__pb2._TRAJCONDITION
_WAITTRAJREQ.fields_by_name['set_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITTRAJREQ.fields_by_name['set_end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITTRAJREQ.fields_by_name['set_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITTRAJREQ.fields_by_name['set_end_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITRADIUSREQ.fields_by_name['set_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITRADIUSREQ.fields_by_name['set_end_do_list'].message_type = device__msgs__pb2._DIGITALSIGNAL
_WAITRADIUSREQ.fields_by_name['set_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_WAITRADIUSREQ.fields_by_name['set_end_ao_list'].message_type = device__msgs__pb2._ANALOGSIGNAL
_TUNINGPROGRAM.fields_by_name['program'].message_type = _PROGRAM
_TUNINGPROGRAM.fields_by_name['tuning_space'].enum_type = common__msgs__pb2._TUNINGSPACE
_TUNINGPROGRAM.fields_by_name['precision'].enum_type = common__msgs__pb2._TUNINGPRECISION
_MODBUSVARIABLE.fields_by_name['signal_type'].enum_type = _MODBUSVARIABLE_SIGNALTYPE
_MODBUSVARIABLE_SIGNALTYPE.containing_type = _MODBUSVARIABLE
_MODBUSSERVER.fields_by_name['variable_list'].message_type = _MODBUSVARIABLE
_MODBUSVARIABLELIST.fields_by_name['modbus_variables'].message_type = _MODBUSSERVER
_ALLVARS.fields_by_name['variables'].message_type = _VARIABLE
_INTVARS.fields_by_name['variables'].message_type = _INTVARIABLE
_MODBUSVARS.fields_by_name['variables'].message_type = _MODBUSVARIABLE
_BOOLVARS.fields_by_name['variables'].message_type = _BOOLVARIABLE
_FLOATVARS.fields_by_name['variables'].message_type = _FLOATVARIABLE
_JPOSVARS.fields_by_name['variables'].message_type = _JPOSVARIABLE
_TPOSVARS.fields_by_name['variables'].message_type = _TPOSVARIABLE
_INVERSEKINEMATICSRES.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CHECKAPROACHRETRACTVALIDRES.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_GETPALLETPOINTLISTRES.fields_by_name['pallet_points'].message_type = _PALLETPOINT
_GETPALLETPOINTLISTRES.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CALCULATERELATIVEPOSEREQ.fields_by_name['base_type'].enum_type = _TASKBASETYPE
_CALCULATERELATIVEPOSERES.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CALCULATECURRENTPOSERELREQ.fields_by_name['base_type'].enum_type = _TASKBASETYPE
_CALCULATECURRENTPOSERELRES.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_TELEOPDEVICE.fields_by_name['type'].enum_type = _TELEOPDEVICE_TELEOPDEVICETYPE
_TELEOPDEVICE_TELEOPDEVICETYPE.containing_type = _TELEOPDEVICE
_TELEOPSTATE.fields_by_name['mode'].enum_type = _TELEMODE
_TELEOPSTATE.fields_by_name['method'].enum_type = _TELEMETHOD
_TELEP.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_TELEOPFILELIST.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_MOVETELEJREQ.fields_by_name['method'].enum_type = _TELEMETHOD
_MOVETELELREQ.fields_by_name['method'].enum_type = _TELEMETHOD
_MOVEFLREQ.fields_by_name['target'].message_type = _TARGETP
_MOVEFLREQ.fields_by_name['blending'].message_type = _BLENDINGTYPE
_MOVEFLREQ.fields_by_name['vel_type'].enum_type = _VELOCITYMODETYPE
_MOVEFLREQ.fields_by_name['post_condition'].message_type = _MOTIONCONDITION
DESCRIPTOR.message_types_by_name['ControlInfo'] = _CONTROLINFO
DESCRIPTOR.message_types_by_name['SDKLicenseInfo'] = _SDKLICENSEINFO
DESCRIPTOR.message_types_by_name['SDKLicenseResp'] = _SDKLICENSERESP
DESCRIPTOR.message_types_by_name['VariableCondition'] = _VARIABLECONDITION
DESCRIPTOR.message_types_by_name['IOCondition'] = _IOCONDITION
DESCRIPTOR.message_types_by_name['MotionCondition'] = _MOTIONCONDITION
DESCRIPTOR.message_types_by_name['BlendingType'] = _BLENDINGTYPE
DESCRIPTOR.message_types_by_name['TargetJ'] = _TARGETJ
DESCRIPTOR.message_types_by_name['MoveJReq'] = _MOVEJREQ
DESCRIPTOR.message_types_by_name['MoveJCondReq'] = _MOVEJCONDREQ
DESCRIPTOR.message_types_by_name['MoveJTReq'] = _MOVEJTREQ
DESCRIPTOR.message_types_by_name['TargetP'] = _TARGETP
DESCRIPTOR.message_types_by_name['TargetC'] = _TARGETC
DESCRIPTOR.message_types_by_name['MoveLReq'] = _MOVELREQ
DESCRIPTOR.message_types_by_name['MoveLTReq'] = _MOVELTREQ
DESCRIPTOR.message_types_by_name['MoveCReq'] = _MOVECREQ
DESCRIPTOR.message_types_by_name['MoveCTReq'] = _MOVECTREQ
DESCRIPTOR.message_types_by_name['WaitIOReq'] = _WAITIOREQ
DESCRIPTOR.message_types_by_name['WaitTimeReq'] = _WAITTIMEREQ
DESCRIPTOR.message_types_by_name['WaitProgressReq'] = _WAITPROGRESSREQ
DESCRIPTOR.message_types_by_name['WaitTrajReq'] = _WAITTRAJREQ
DESCRIPTOR.message_types_by_name['WaitRadiusReq'] = _WAITRADIUSREQ
DESCRIPTOR.message_types_by_name['Program'] = _PROGRAM
DESCRIPTOR.message_types_by_name['TuningProgram'] = _TUNINGPROGRAM
DESCRIPTOR.message_types_by_name['ProgramInfo'] = _PROGRAMINFO
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['IntVariable'] = _INTVARIABLE
DESCRIPTOR.message_types_by_name['ModbusVariable'] = _MODBUSVARIABLE
DESCRIPTOR.message_types_by_name['BoolVariable'] = _BOOLVARIABLE
DESCRIPTOR.message_types_by_name['FloatVariable'] = _FLOATVARIABLE
DESCRIPTOR.message_types_by_name['JPosVariable'] = _JPOSVARIABLE
DESCRIPTOR.message_types_by_name['TPosVariable'] = _TPOSVARIABLE
DESCRIPTOR.message_types_by_name['ModbusServer'] = _MODBUSSERVER
DESCRIPTOR.message_types_by_name['ModbusVariableList'] = _MODBUSVARIABLELIST
DESCRIPTOR.message_types_by_name['AllVars'] = _ALLVARS
DESCRIPTOR.message_types_by_name['IntVars'] = _INTVARS
DESCRIPTOR.message_types_by_name['ModbusVars'] = _MODBUSVARS
DESCRIPTOR.message_types_by_name['BoolVars'] = _BOOLVARS
DESCRIPTOR.message_types_by_name['FloatVars'] = _FLOATVARS
DESCRIPTOR.message_types_by_name['JPosVars'] = _JPOSVARS
DESCRIPTOR.message_types_by_name['TPosVars'] = _TPOSVARS
DESCRIPTOR.message_types_by_name['InverseKinematicsReq'] = _INVERSEKINEMATICSREQ
DESCRIPTOR.message_types_by_name['InverseKinematicsRes'] = _INVERSEKINEMATICSRES
DESCRIPTOR.message_types_by_name['CheckAproachRetractValidReq'] = _CHECKAPROACHRETRACTVALIDREQ
DESCRIPTOR.message_types_by_name['CheckAproachRetractValidRes'] = _CHECKAPROACHRETRACTVALIDRES
DESCRIPTOR.message_types_by_name['GetPalletPointListReq'] = _GETPALLETPOINTLISTREQ
DESCRIPTOR.message_types_by_name['PalletPoint'] = _PALLETPOINT
DESCRIPTOR.message_types_by_name['GetPalletPointListRes'] = _GETPALLETPOINTLISTRES
DESCRIPTOR.message_types_by_name['CalculateRelativePoseReq'] = _CALCULATERELATIVEPOSEREQ
DESCRIPTOR.message_types_by_name['CalculateRelativePoseRes'] = _CALCULATERELATIVEPOSERES
DESCRIPTOR.message_types_by_name['CalculateCurrentPoseRelReq'] = _CALCULATECURRENTPOSERELREQ
DESCRIPTOR.message_types_by_name['CalculateCurrentPoseRelRes'] = _CALCULATECURRENTPOSERELRES
DESCRIPTOR.message_types_by_name['TeleOpDevice'] = _TELEOPDEVICE
DESCRIPTOR.message_types_by_name['TeleOpState'] = _TELEOPSTATE
DESCRIPTOR.message_types_by_name['TeleP'] = _TELEP
DESCRIPTOR.message_types_by_name['TeleOpFileList'] = _TELEOPFILELIST
DESCRIPTOR.message_types_by_name['TeleFileReq'] = _TELEFILEREQ
DESCRIPTOR.message_types_by_name['TelePlayRate'] = _TELEPLAYRATE
DESCRIPTOR.message_types_by_name['MoveTeleJReq'] = _MOVETELEJREQ
DESCRIPTOR.message_types_by_name['MoveTeleLReq'] = _MOVETELELREQ
DESCRIPTOR.message_types_by_name['MoveFLReq'] = _MOVEFLREQ
DESCRIPTOR.message_types_by_name['MoveFLRes'] = _MOVEFLRES
DESCRIPTOR.enum_types_by_name['JointBaseType'] = _JOINTBASETYPE
DESCRIPTOR.enum_types_by_name['TaskBaseType'] = _TASKBASETYPE
DESCRIPTOR.enum_types_by_name['VelocityModeType'] = _VELOCITYMODETYPE
DESCRIPTOR.enum_types_by_name['CircularSettingType'] = _CIRCULARSETTINGTYPE
DESCRIPTOR.enum_types_by_name['CircularMovingType'] = _CIRCULARMOVINGTYPE
DESCRIPTOR.enum_types_by_name['TeleMode'] = _TELEMODE
DESCRIPTOR.enum_types_by_name['TeleMethod'] = _TELEMETHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlInfo = _reflection.GeneratedProtocolMessageType('ControlInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLINFO,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ControlInfo)
  })
_sym_db.RegisterMessage(ControlInfo)

SDKLicenseInfo = _reflection.GeneratedProtocolMessageType('SDKLicenseInfo', (_message.Message,), {
  'DESCRIPTOR' : _SDKLICENSEINFO,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDKLicenseInfo)
  })
_sym_db.RegisterMessage(SDKLicenseInfo)

SDKLicenseResp = _reflection.GeneratedProtocolMessageType('SDKLicenseResp', (_message.Message,), {
  'DESCRIPTOR' : _SDKLICENSERESP,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDKLicenseResp)
  })
_sym_db.RegisterMessage(SDKLicenseResp)

VariableCondition = _reflection.GeneratedProtocolMessageType('VariableCondition', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLECONDITION,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.VariableCondition)
  })
_sym_db.RegisterMessage(VariableCondition)

IOCondition = _reflection.GeneratedProtocolMessageType('IOCondition', (_message.Message,), {
  'DESCRIPTOR' : _IOCONDITION,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOCondition)
  })
_sym_db.RegisterMessage(IOCondition)

MotionCondition = _reflection.GeneratedProtocolMessageType('MotionCondition', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONCONDITION,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotionCondition)
  })
_sym_db.RegisterMessage(MotionCondition)

BlendingType = _reflection.GeneratedProtocolMessageType('BlendingType', (_message.Message,), {
  'DESCRIPTOR' : _BLENDINGTYPE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BlendingType)
  })
_sym_db.RegisterMessage(BlendingType)

TargetJ = _reflection.GeneratedProtocolMessageType('TargetJ', (_message.Message,), {
  'DESCRIPTOR' : _TARGETJ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TargetJ)
  })
_sym_db.RegisterMessage(TargetJ)

MoveJReq = _reflection.GeneratedProtocolMessageType('MoveJReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVEJREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveJReq)
  })
_sym_db.RegisterMessage(MoveJReq)

MoveJCondReq = _reflection.GeneratedProtocolMessageType('MoveJCondReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVEJCONDREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveJCondReq)
  })
_sym_db.RegisterMessage(MoveJCondReq)

MoveJTReq = _reflection.GeneratedProtocolMessageType('MoveJTReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVEJTREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveJTReq)
  })
_sym_db.RegisterMessage(MoveJTReq)

TargetP = _reflection.GeneratedProtocolMessageType('TargetP', (_message.Message,), {
  'DESCRIPTOR' : _TARGETP,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TargetP)
  })
_sym_db.RegisterMessage(TargetP)

TargetC = _reflection.GeneratedProtocolMessageType('TargetC', (_message.Message,), {
  'DESCRIPTOR' : _TARGETC,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TargetC)
  })
_sym_db.RegisterMessage(TargetC)

MoveLReq = _reflection.GeneratedProtocolMessageType('MoveLReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVELREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveLReq)
  })
_sym_db.RegisterMessage(MoveLReq)

MoveLTReq = _reflection.GeneratedProtocolMessageType('MoveLTReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVELTREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveLTReq)
  })
_sym_db.RegisterMessage(MoveLTReq)

MoveCReq = _reflection.GeneratedProtocolMessageType('MoveCReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVECREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveCReq)
  })
_sym_db.RegisterMessage(MoveCReq)

MoveCTReq = _reflection.GeneratedProtocolMessageType('MoveCTReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVECTREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveCTReq)
  })
_sym_db.RegisterMessage(MoveCTReq)

WaitIOReq = _reflection.GeneratedProtocolMessageType('WaitIOReq', (_message.Message,), {
  'DESCRIPTOR' : _WAITIOREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.WaitIOReq)
  })
_sym_db.RegisterMessage(WaitIOReq)

WaitTimeReq = _reflection.GeneratedProtocolMessageType('WaitTimeReq', (_message.Message,), {
  'DESCRIPTOR' : _WAITTIMEREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.WaitTimeReq)
  })
_sym_db.RegisterMessage(WaitTimeReq)

WaitProgressReq = _reflection.GeneratedProtocolMessageType('WaitProgressReq', (_message.Message,), {
  'DESCRIPTOR' : _WAITPROGRESSREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.WaitProgressReq)
  })
_sym_db.RegisterMessage(WaitProgressReq)

WaitTrajReq = _reflection.GeneratedProtocolMessageType('WaitTrajReq', (_message.Message,), {
  'DESCRIPTOR' : _WAITTRAJREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.WaitTrajReq)
  })
_sym_db.RegisterMessage(WaitTrajReq)

WaitRadiusReq = _reflection.GeneratedProtocolMessageType('WaitRadiusReq', (_message.Message,), {
  'DESCRIPTOR' : _WAITRADIUSREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.WaitRadiusReq)
  })
_sym_db.RegisterMessage(WaitRadiusReq)

Program = _reflection.GeneratedProtocolMessageType('Program', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAM,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Program)
  })
_sym_db.RegisterMessage(Program)

TuningProgram = _reflection.GeneratedProtocolMessageType('TuningProgram', (_message.Message,), {
  'DESCRIPTOR' : _TUNINGPROGRAM,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TuningProgram)
  })
_sym_db.RegisterMessage(TuningProgram)

ProgramInfo = _reflection.GeneratedProtocolMessageType('ProgramInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMINFO,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ProgramInfo)
  })
_sym_db.RegisterMessage(ProgramInfo)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Variable)
  })
_sym_db.RegisterMessage(Variable)

IntVariable = _reflection.GeneratedProtocolMessageType('IntVariable', (_message.Message,), {
  'DESCRIPTOR' : _INTVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IntVariable)
  })
_sym_db.RegisterMessage(IntVariable)

ModbusVariable = _reflection.GeneratedProtocolMessageType('ModbusVariable', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ModbusVariable)
  })
_sym_db.RegisterMessage(ModbusVariable)

BoolVariable = _reflection.GeneratedProtocolMessageType('BoolVariable', (_message.Message,), {
  'DESCRIPTOR' : _BOOLVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BoolVariable)
  })
_sym_db.RegisterMessage(BoolVariable)

FloatVariable = _reflection.GeneratedProtocolMessageType('FloatVariable', (_message.Message,), {
  'DESCRIPTOR' : _FLOATVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FloatVariable)
  })
_sym_db.RegisterMessage(FloatVariable)

JPosVariable = _reflection.GeneratedProtocolMessageType('JPosVariable', (_message.Message,), {
  'DESCRIPTOR' : _JPOSVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.JPosVariable)
  })
_sym_db.RegisterMessage(JPosVariable)

TPosVariable = _reflection.GeneratedProtocolMessageType('TPosVariable', (_message.Message,), {
  'DESCRIPTOR' : _TPOSVARIABLE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TPosVariable)
  })
_sym_db.RegisterMessage(TPosVariable)

ModbusServer = _reflection.GeneratedProtocolMessageType('ModbusServer', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSSERVER,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ModbusServer)
  })
_sym_db.RegisterMessage(ModbusServer)

ModbusVariableList = _reflection.GeneratedProtocolMessageType('ModbusVariableList', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSVARIABLELIST,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ModbusVariableList)
  })
_sym_db.RegisterMessage(ModbusVariableList)

AllVars = _reflection.GeneratedProtocolMessageType('AllVars', (_message.Message,), {
  'DESCRIPTOR' : _ALLVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.AllVars)
  })
_sym_db.RegisterMessage(AllVars)

IntVars = _reflection.GeneratedProtocolMessageType('IntVars', (_message.Message,), {
  'DESCRIPTOR' : _INTVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IntVars)
  })
_sym_db.RegisterMessage(IntVars)

ModbusVars = _reflection.GeneratedProtocolMessageType('ModbusVars', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ModbusVars)
  })
_sym_db.RegisterMessage(ModbusVars)

BoolVars = _reflection.GeneratedProtocolMessageType('BoolVars', (_message.Message,), {
  'DESCRIPTOR' : _BOOLVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BoolVars)
  })
_sym_db.RegisterMessage(BoolVars)

FloatVars = _reflection.GeneratedProtocolMessageType('FloatVars', (_message.Message,), {
  'DESCRIPTOR' : _FLOATVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FloatVars)
  })
_sym_db.RegisterMessage(FloatVars)

JPosVars = _reflection.GeneratedProtocolMessageType('JPosVars', (_message.Message,), {
  'DESCRIPTOR' : _JPOSVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.JPosVars)
  })
_sym_db.RegisterMessage(JPosVars)

TPosVars = _reflection.GeneratedProtocolMessageType('TPosVars', (_message.Message,), {
  'DESCRIPTOR' : _TPOSVARS,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TPosVars)
  })
_sym_db.RegisterMessage(TPosVars)

InverseKinematicsReq = _reflection.GeneratedProtocolMessageType('InverseKinematicsReq', (_message.Message,), {
  'DESCRIPTOR' : _INVERSEKINEMATICSREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.InverseKinematicsReq)
  })
_sym_db.RegisterMessage(InverseKinematicsReq)

InverseKinematicsRes = _reflection.GeneratedProtocolMessageType('InverseKinematicsRes', (_message.Message,), {
  'DESCRIPTOR' : _INVERSEKINEMATICSRES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.InverseKinematicsRes)
  })
_sym_db.RegisterMessage(InverseKinematicsRes)

CheckAproachRetractValidReq = _reflection.GeneratedProtocolMessageType('CheckAproachRetractValidReq', (_message.Message,), {
  'DESCRIPTOR' : _CHECKAPROACHRETRACTVALIDREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CheckAproachRetractValidReq)
  })
_sym_db.RegisterMessage(CheckAproachRetractValidReq)

CheckAproachRetractValidRes = _reflection.GeneratedProtocolMessageType('CheckAproachRetractValidRes', (_message.Message,), {
  'DESCRIPTOR' : _CHECKAPROACHRETRACTVALIDRES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CheckAproachRetractValidRes)
  })
_sym_db.RegisterMessage(CheckAproachRetractValidRes)

GetPalletPointListReq = _reflection.GeneratedProtocolMessageType('GetPalletPointListReq', (_message.Message,), {
  'DESCRIPTOR' : _GETPALLETPOINTLISTREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GetPalletPointListReq)
  })
_sym_db.RegisterMessage(GetPalletPointListReq)

PalletPoint = _reflection.GeneratedProtocolMessageType('PalletPoint', (_message.Message,), {
  'DESCRIPTOR' : _PALLETPOINT,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.PalletPoint)
  })
_sym_db.RegisterMessage(PalletPoint)

GetPalletPointListRes = _reflection.GeneratedProtocolMessageType('GetPalletPointListRes', (_message.Message,), {
  'DESCRIPTOR' : _GETPALLETPOINTLISTRES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GetPalletPointListRes)
  })
_sym_db.RegisterMessage(GetPalletPointListRes)

CalculateRelativePoseReq = _reflection.GeneratedProtocolMessageType('CalculateRelativePoseReq', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATERELATIVEPOSEREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CalculateRelativePoseReq)
  })
_sym_db.RegisterMessage(CalculateRelativePoseReq)

CalculateRelativePoseRes = _reflection.GeneratedProtocolMessageType('CalculateRelativePoseRes', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATERELATIVEPOSERES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CalculateRelativePoseRes)
  })
_sym_db.RegisterMessage(CalculateRelativePoseRes)

CalculateCurrentPoseRelReq = _reflection.GeneratedProtocolMessageType('CalculateCurrentPoseRelReq', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATECURRENTPOSERELREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CalculateCurrentPoseRelReq)
  })
_sym_db.RegisterMessage(CalculateCurrentPoseRelReq)

CalculateCurrentPoseRelRes = _reflection.GeneratedProtocolMessageType('CalculateCurrentPoseRelRes', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATECURRENTPOSERELRES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CalculateCurrentPoseRelRes)
  })
_sym_db.RegisterMessage(CalculateCurrentPoseRelRes)

TeleOpDevice = _reflection.GeneratedProtocolMessageType('TeleOpDevice', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPDEVICE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TeleOpDevice)
  })
_sym_db.RegisterMessage(TeleOpDevice)

TeleOpState = _reflection.GeneratedProtocolMessageType('TeleOpState', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPSTATE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TeleOpState)
  })
_sym_db.RegisterMessage(TeleOpState)

TeleP = _reflection.GeneratedProtocolMessageType('TeleP', (_message.Message,), {
  'DESCRIPTOR' : _TELEP,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TeleP)
  })
_sym_db.RegisterMessage(TeleP)

TeleOpFileList = _reflection.GeneratedProtocolMessageType('TeleOpFileList', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPFILELIST,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TeleOpFileList)
  })
_sym_db.RegisterMessage(TeleOpFileList)

TeleFileReq = _reflection.GeneratedProtocolMessageType('TeleFileReq', (_message.Message,), {
  'DESCRIPTOR' : _TELEFILEREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TeleFileReq)
  })
_sym_db.RegisterMessage(TeleFileReq)

TelePlayRate = _reflection.GeneratedProtocolMessageType('TelePlayRate', (_message.Message,), {
  'DESCRIPTOR' : _TELEPLAYRATE,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TelePlayRate)
  })
_sym_db.RegisterMessage(TelePlayRate)

MoveTeleJReq = _reflection.GeneratedProtocolMessageType('MoveTeleJReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVETELEJREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveTeleJReq)
  })
_sym_db.RegisterMessage(MoveTeleJReq)

MoveTeleLReq = _reflection.GeneratedProtocolMessageType('MoveTeleLReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVETELELREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveTeleLReq)
  })
_sym_db.RegisterMessage(MoveTeleLReq)

MoveFLReq = _reflection.GeneratedProtocolMessageType('MoveFLReq', (_message.Message,), {
  'DESCRIPTOR' : _MOVEFLREQ,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveFLReq)
  })
_sym_db.RegisterMessage(MoveFLReq)

MoveFLRes = _reflection.GeneratedProtocolMessageType('MoveFLRes', (_message.Message,), {
  'DESCRIPTOR' : _MOVEFLRES,
  '__module__' : 'control_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MoveFLRes)
  })
_sym_db.RegisterMessage(MoveFLRes)


# @@protoc_insertion_point(module_scope)
